"""Registration module for image validators."""

from axm.catalog.validation.registry import ValidatorRegistry
from axm_image.validation.image import ImageValidator


def register_validators() -> None:
    """Register image validators."""
    ValidatorRegistry.register("image", ImageValidator)
