"""Registration logic for image entry types."""

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from axm.catalog.entries.registry import EntryTypeRegistry


def register_entries(registry: type["EntryTypeRegistry"]) -> None:
    """Register image entry types."""
    from axm_image.entries.image import ImageEntry

    registry.register("data", "image", ImageEntry)
